==> amphi-etl-0.8.18.tar.gz: amphi-etl-0.8.18/packages/theme-light/src/icons.ts <==
import { LabIcon } from '@jupyterlab/ui-components';

import folderIconSvgStr from '../style/icons/folder-24.svg';
import saveIconSvgStr from '../style/icons/save-24.svg';
import terminalScreenIconSvgStr from '../style/icons/terminal-screen-24.svg';
import playIconSvgStr from '../style/icons/play-24.svg';
import fileSourceIconSvgStr from '../style/icons/file-source-24.svg';
import folderPlusIconSvgStr from '../style/icons/folder-plus-24.svg';
import uploadIconSvgStr from '../style/icons/upload-24.svg';
import reloadIconSvgStr from '../style/icons/reload-24.svg';
import fileIconSvgStr from '../style/icons/file-24.svg';
import fileCsvIconSvgStr from '../style/icons/file-csv-24.svg';
import filePdfIconSvgStr from '../style/icons/file-pdf-24.svg';
import fileExcelIconSvgStr from '../style/icons/file-excel-24.svg';
import fileParquetIconSvgStr from '../style/icons/file-parquet-24.svg';
import fileJsonIconSvgStr from '../style/icons/file-json-24.svg';
import fileNotebookIconSvgStr from '../style/icons/file-ipynb-24.svg';
import terminalIconSvgStr from '../style/icons/terminal-screen-24.svg';
import homeIconSvgStr from '../style/icons/home-24.svg';
import searchIconSvgStr from '../style/icons/search-24.svg';


export const terminalIcon = new LabIcon({
  name: 'amphi:terminal-amphi-icon',
  svgstr: terminalIconSvgStr
});

export const folderAmphiIcon = new LabIcon({
  name: 'amphi:folder-icon',
  svgstr: folderIconSvgStr
});

export const saveAmphiIcon = new LabIcon({
  name: 'amphi:save-icon',
  svgstr: saveIconSvgStr
});

export const terminalScreenAmphiIcon = new LabIcon({
  name: 'amphi:terminal-screen-icon',
  svgstr: terminalScreenIconSvgStr
});

export const playAmphiIcon = new LabIcon({
  name: 'amphi:play-icon',
  svgstr: playIconSvgStr
});

export const fileSourceAmphiIcon = new LabIcon({
  name: 'amphi:file-source-icon',
  svgstr: fileSourceIconSvgStr
});

export const folderPlusAmphiIcon = new LabIcon({
  name: 'amphi:folder-plus-icon',
  svgstr: folderPlusIconSvgStr
});

export const uploadAmphiIcon = new LabIcon({
  name: 'amphi:upload-icon',
  svgstr: uploadIconSvgStr
});

export const reloadAmphiIcon = new LabIcon({
  name: 'amphi:reload-icon',
  svgstr: reloadIconSvgStr
});

export const fileAmphiIcon = new LabIcon({
  name: 'amphi:file-icon',
  svgstr: fileIconSvgStr
});

export const fileCsvAmphiIcon = new LabIcon({
  name: 'amphi:file-csv-icon',
  svgstr: fileCsvIconSvgStr
});

export const filePdfAmphiIcon = new LabIcon({
  name: 'amphi:file-pdf-icon',
  svgstr: filePdfIconSvgStr
});

export const fileJsonAmphiIcon = new LabIcon({
  name: 'amphi:file-json-icon',
  svgstr: fileJsonIconSvgStr
});

export const fileExcelAmphiIcon = new LabIcon({
  name: 'amphi:file-excel-icon',
  svgstr: fileExcelIconSvgStr
});

export const fileParquetAmphiIcon = new LabIcon({
  name: 'amphi:file-parquet-icon',
  svgstr: fileParquetIconSvgStr
});

export const fileNotebookIcon = new LabIcon({
  name: 'amphi:file-notebook-icon',
  svgstr: fileNotebookIconSvgStr
});

export const homeAmphiIcon = new LabIcon({
  name: 'amphi:home-icon',
  svgstr: homeIconSvgStr
});

export const searchAmphiIcon = new LabIcon({
  name: 'amphi:search-icon',
  svgstr: searchIconSvgStr
});

==> amphi-etl-0.9.0a3.tar.gz: amphi-etl-0.9.0a3/packages/theme-light/src/icons.ts <==
import { LabIcon } from '@jupyterlab/ui-components';

import folderIconSvgStr from '../style/icons/folder.svg';
import saveIconSvgStr from '../style/icons/save.svg';
import playIconSvgStr from '../style/icons/play.svg';
import fileSourceIconSvgStr from '../style/icons/code.svg';
import folderPlusIconSvgStr from '../style/icons/folder-plus.svg';
import uploadIconSvgStr from '../style/icons/upload.svg';
import reloadIconSvgStr from '../style/icons/refresh.svg';
import fileIconSvgStr from '../style/icons/file-24.svg';
import fileCsvIconSvgStr from '../style/icons/file-csv-24.svg';
import filePdfIconSvgStr from '../style/icons/file-pdf-24.svg';
import fileExcelIconSvgStr from '../style/icons/file-excel-24.svg';
import fileParquetIconSvgStr from '../style/icons/file-parquet-24.svg';
import fileJsonIconSvgStr from '../style/icons/file-json-24.svg';
import fileNotebookIconSvgStr from '../style/icons/file-ipynb-24.svg';
import consoleIconSvgStr from '../style/icons/console.svg';
import homeIconSvgStr from '../style/icons/home.svg';
import searchIconSvgStr from '../style/icons/search.svg';


export const consoleIcon = new LabIcon({
  name: 'amphi:terminal-amphi-icon',
  svgstr: consoleIconSvgStr
});

export const folderAmphiIcon = new LabIcon({
  name: 'amphi:folder-icon',
  svgstr: folderIconSvgStr
});

export const saveAmphiIcon = new LabIcon({
  name: 'amphi:save-icon',
  svgstr: saveIconSvgStr
});

export const playAmphiIcon = new LabIcon({
  name: 'amphi:play-icon',
  svgstr: playIconSvgStr
});

export const fileSourceAmphiIcon = new LabIcon({
  name: 'amphi:file-source-icon',
  svgstr: fileSourceIconSvgStr
});

export const folderPlusAmphiIcon = new LabIcon({
  name: 'amphi:folder-plus-icon',
  svgstr: folderPlusIconSvgStr
});

export const uploadAmphiIcon = new LabIcon({
  name: 'amphi:upload-icon',
  svgstr: uploadIconSvgStr
});

export const reloadAmphiIcon = new LabIcon({
  name: 'amphi:reload-icon',
  svgstr: reloadIconSvgStr
});

export const fileAmphiIcon = new LabIcon({
  name: 'amphi:file-icon',
  svgstr: fileIconSvgStr
});

export const fileCsvAmphiIcon = new LabIcon({
  name: 'amphi:file-csv-icon',
  svgstr: fileCsvIconSvgStr
});

export const filePdfAmphiIcon = new LabIcon({
  name: 'amphi:file-pdf-icon',
  svgstr: filePdfIconSvgStr
});

export const fileJsonAmphiIcon = new LabIcon({
  name: 'amphi:file-json-icon',
  svgstr: fileJsonIconSvgStr
});

export const fileExcelAmphiIcon = new LabIcon({
  name: 'amphi:file-excel-icon',
  svgstr: fileExcelIconSvgStr
});

export const fileParquetAmphiIcon = new LabIcon({
  name: 'amphi:file-parquet-icon',
  svgstr: fileParquetIconSvgStr
});

export const fileNotebookIcon = new LabIcon({
  name: 'amphi:file-notebook-icon',
  svgstr: fileNotebookIconSvgStr
});

export const homeAmphiIcon = new LabIcon({
  name: 'amphi:home-icon',
  svgstr: homeIconSvgStr
});

export const searchAmphiIcon = new LabIcon({
  name: 'amphi:search-icon',
  svgstr: searchIconSvgStr
});
